import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import {AdminAuthGuard} from "src/core/guards/admin-auth.guard";
import {Constants} from "src/utils/constants";
import {HeaderCmsService} from "./header-cms.service";
import {UpdateHeaderCmsDto} from "./dto/update-header-cms.dto";
import {FileFieldsInterceptor} from "@nestjs/platform-express";
import {UploadedMulterFileI} from "src/modules/SpacesModule/SpacesService";

@Controller({path: "header-cms", version: Constants.API_VERSION_1})

export class HeaderCmsController {
    constructor(private readonly service: HeaderCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            {name: "logo", maxCount: 1}
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateHeaderCmsDto,
        @UploadedFiles() files: {
            logo: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
