import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors,
} from '@nestjs/common';
import {AdminAuthGuard} from 'src/core/guards/admin-auth.guard';
import {Constants} from 'src/utils/constants';
import {ReeferFriendCmsService} from './reefer-friend-cms.service';
import {UpdateReeferFriendCmsDto} from './dto/update-reefer-friend-cms.dto';
import {FileFieldsInterceptor} from '@nestjs/platform-express';
import {UploadedMulterFileI} from 'src/modules/SpacesModule/SpacesService';

@Controller({path: 'reefer-friend-cms', version: Constants.API_VERSION_1})
export class ReeferFriendCmsController {
    constructor(private readonly service: ReeferFriendCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([{name: 'image', maxCount: 1}]))
    updateOrCreateData(
        @Body() dto: UpdateReeferFriendCmsDto,
        @UploadedFiles()
            files: {
            image: UploadedMulterFileI;
        },
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
